<?php
session_start();
require_once __DIR__ . '/db.php';

function debug($data){
    echo '<pre>' . print_r($data, 1) . '</pre>';
}

function getToken(){
    if(empty($_SESSION['token'])){
        $_SESSION['token'] = uniqid('', true);
    }
    return password_hash( $_SESSION['token'], PASSWORD_DEFAULT );
}

function checkToken($token){
    return password_verify($_SESSION['token'], $token);
}

if($_GET['do'] == 'logout'){
    unset($_SESSION['auth']);
    header("Location: {$_SERVER['PHP_SELF']}");
}

if(!empty($_POST['login'])){
    $login = $_POST['login'];
    $pass = $_POST['pass'];
    $stmt = $pdo->prepare("SELECT * FROM users WHERE login = ?");
    $stmt->execute([$login]);
    $data = $stmt->fetch();
    if($data){
        if(password_verify($pass, $data['pass'])){
            $_SESSION['auth']['id'] = $data['id'];
            $_SESSION['auth']['login'] = $data['login'];
        }
    }
    header("Location: {$_SERVER['PHP_SELF']}");
    die;
}

if(!empty($_POST['post'])){
    if(empty($_SESSION['auth']['login'])){
        $_SESSION['error'] = 'Авторизуйтесь, чтобы оставить сообщение';
        header("Location: {$_SERVER['PHP_SELF']}");
        die;
    }
    $token = $_POST['token'] ?? '';
    if(!checkToken($token)){
        $_SESSION['error'] = 'Ошибка безопасности';
        unset($_SESSION['token']);
        unset($_SESSION['auth']);
        header("Location: {$_SERVER['PHP_SELF']}");
        die;
    }
    $stmt = $pdo->prepare("INSERT INTO posts (post, user) VALUES (?, ?)");
    $stmt->execute([$_POST['post'], $_SESSION['auth']['login']]);
    $_SESSION['ok'] = 'Сообщение добавлено';
    header("Location: {$_SERVER['PHP_SELF']}");
    die;
}

?>
<!doctype html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport"
          content="width=device-width, user-scalable=no, initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>Document</title>
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0-beta/css/bootstrap.min.css" integrity="sha384-/Y6pD6FV/Vv2HJnA6t+vslU6fwYXjCFtcEpHbNJ0lyAFsXTsjBbfaDjzALeQsN6M" crossorigin="anonymous">
</head>
<body>

<div class="container">
    <div class="row">
        <div class="col-md-6">
            <?php if(isset($_SESSION['auth'])): ?>
                <h3>Welcome, <?= $_SESSION['auth']['login'] ?></h3>
                <a href="?do=logout">Logout</a>
                <form method="post">
                    <div class="form-group">
                        <label for="text">Text</label>
                        <textarea class="form-control" name="post" id="text"></textarea>
                    </div>
                    <input type="hidden" name="token" value="<?= getToken() ?>">
                    <button type="submit" class="btn btn-primary">Submit</button>
                </form>
            <?php else: ?>
                <form method="post">
                    <div class="form-group">
                        <label for="login">Login</label>
                        <input type="text" name="login" class="form-control" id="password" placeholder="Login">
                    </div>
                    <div class="form-group">
                        <label for="password">Password</label>
                        <input type="password" name="pass" class="form-control" id="password" placeholder="Password">
                    </div>
                    <button type="submit" class="btn btn-primary">Submit</button>
                </form>
            <?php endif; ?>


            <?php if(isset($_SESSION['error'])): ?>
                <div class="alert alert-danger" role="alert">
                    <?php echo $_SESSION['error']; unset($_SESSION['error']); ?>
                </div>
            <?php endif; ?>
            <?php if(isset($_SESSION['ok'])): ?>
                <div class="alert alert-success" role="alert">
                    <?php echo $_SESSION['ok']; unset($_SESSION['ok']); ?>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>

</body>
</html>